aboutsummaryrefslogtreecommitdiff
path: root/tests/client
diff options
context:
space:
mode:
authorJakub Jelen <jjelen@redhat.com>2019-05-30 15:08:21 +0200
committerAndreas Schneider <asn@cryptomilk.org>2019-06-13 11:00:56 +0200
commit63f477181a86de186f5b038c87f4ff4c01a50bd4 (patch)
tree4d4a2ee593e32bbe9eebe84c9b87faad14fedcee /tests/client
parent2c385c0e13b9410429d1871504d320d59be93e9c (diff)
downloadlibssh-63f477181a86de186f5b038c87f4ff4c01a50bd4.tar.gz
libssh-63f477181a86de186f5b038c87f4ff4c01a50bd4.tar.xz
libssh-63f477181a86de186f5b038c87f4ff4c01a50bd4.zip
tests: The DSA is not available in mbedtls
Signed-off-by: Jakub Jelen <jjelen@redhat.com> Reviewed-by: Andreas Schneider <asn@cryptomilk.org>
Diffstat (limited to 'tests/client')
-rw-r--r--tests/client/torture_auth.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/tests/client/torture_auth.c b/tests/client/torture_auth.c
index aea76d32..aea6bda9 100644
--- a/tests/client/torture_auth.c
+++ b/tests/client/torture_auth.c
@@ -693,9 +693,9 @@ static void torture_auth_pubkey_types_ed25519(void **state)
rc = ssh_userauth_list(session, NULL);
assert_true(rc & SSH_AUTH_METHOD_PUBLICKEY);
/* Enable only DSA keys -- authentication should fail */
rc = ssh_options_set(session, SSH_OPTIONS_PUBLICKEY_ACCEPTED_TYPES,
- "ssh-dss");
+ "ssh-rsa");
assert_ssh_return_code(session, rc);
rc = ssh_userauth_publickey_auto(session, NULL, NULL);
@@ -834,9 +834,9 @@ static void torture_auth_pubkey_types_ed25519_nonblocking(void **state)
rc = ssh_userauth_list(session, NULL);
assert_true(rc & SSH_AUTH_METHOD_PUBLICKEY);
/* Enable only DSA keys -- authentication should fail */
rc = ssh_options_set(session, SSH_OPTIONS_PUBLICKEY_ACCEPTED_TYPES,
- "ssh-dss");
+ "ssh-rsa");
assert_ssh_return_code(session, rc);
do {
@@ -693,9 +693,9 @@ static void torture_auth_pubkey_types_ed25519(void **state)
rc = ssh_userauth_list(session, NULL);
assert_true(rc & SSH_AUTH_METHOD_PUBLICKEY);
- /* Enable only DSA keys -- authentication should fail */
+ /* Enable only RSA keys -- authentication should fail */
rc = ssh_options_set(session, SSH_OPTIONS_PUBLICKEY_ACCEPTED_TYPES,
@@ -834,9 +834,9 @@ static void torture_auth_pubkey_types_ed25519_nonblocking(void **state)
rc = ssh_userauth_list(session, NULL);
assert_true(rc & SSH_AUTH_METHOD_PUBLICKEY);
- /* Enable only DSA keys -- authentication should fail */
+ /* Enable only RSA keys -- authentication should fail */
rc = ssh_options_set(session, SSH_OPTIONS_PUBLICKEY_ACCEPTED_TYPES,